@@ -105,7 +105,7 @@ static XF86ModuleVersionInfo VersionRec =
 	MODINFOSTRING1,
 	MODINFOSTRING2,
 	XORG_VERSION_CURRENT,
-	1, 1, 0,
+	PACKAGE_VERSION_MAJOR, PACKAGE_VERSION_MINOR, PACKAGE_VERSION_PATCHLEVEL,
 	ABI_CLASS_XINPUT,
 	ABI_XINPUT_VERSION,
 	MOD_CLASS_XINPUT,
@@ -275,8 +275,6 @@ MuTouchPreInit(InputDriverPtr drv, IDevPtr dev, int flags)
 	priv->proximity = FALSE;
 	priv->button_down = FALSE;
 
-	DBG (9, XisbTrace (priv->buffer, 1));
-
 	MuTNewPacket (priv);
 	if (QueryHardware(local) != Success)
 	{
@@ -538,7 +536,7 @@ ReadInput (LocalDevicePtr local)
 static int
 ControlProc (LocalDevicePtr local, xDeviceCtl * control)
 {
-	xDeviceTSCalibrationCtl *c = (xDeviceTSCalibrationCtl *) control;
+	xDeviceAbsCalibCtl *c = (xDeviceAbsCalibCtl *) control;
 	MuTPrivatePtr priv = (MuTPrivatePtr) (local->private);
 
 	priv->min_x = c->min_x;
